@@ -541,7 +541,7 @@ class surface:
         self.surface_area = surface_area
 
     def subtract(self,other_surface):
-        self.other_surface
+        self.other_surface = other_surface
 
 def marching_cubes(surface_object,resolution=20,k=2,level=0,visualize=False):
     """
