@@ -17,16 +17,16 @@ mesh="""if not terminating:
     os.mkdir('{}')
     os.mkdir('{}')
     os.mkdir('{}')
-    model.write('{}/model_tmp','vtp')
-    mesher.write_mesh('{}'+'/mesh-complete.mesh.vtu')
+    model.write('{}'+os.sep+'model_tmp','vtp')
+    mesher.write_mesh('{}'+os.sep+'mesh-complete.mesh.vtu')
     mesh_out = modeling.PolyData()
     mesh_out.set_surface(mesher.get_surface())
-    mesh_out.write('{}'+'/mesh-complete','exterior.vtp')
+    mesh_out.write('{}'+os.sep+'mesh-complete','exterior.vtp')
     mesh_out.set_surface(mesher.get_face_polydata(walls[0]))
-    mesh_out.write('{}'+'/walls_combined','vtp')
+    mesh_out.write('{}'+os.sep+'walls_combined','vtp')
     for face in mesher.get_model_face_ids():
         if face == walls[0]:
             continue
         mesh_out.set_surface(mesher.get_face_polydata(face))
-        mesh_out.write('{}'+'/cap_{{}}'.format(face),'vtp')
+        mesh_out.write('{}'+os.sep+'cap_{{}}'.format(face),'vtp')
 """
