@@ -5,7 +5,7 @@ import glob
 
 class file_options:
 
-    def __init__(self,inflow=1,gui=True):
+    def __init__(self,time=[0,1],flow=[1,1],gui=True,distal_resistance=0):
         """
         Set the parameters for vascular construction
         and simulation for SimVascular python interface.
@@ -16,7 +16,11 @@ class file_options:
         self.set_mesh_options()
         self.set_pipeline_steps(gui=gui)
         self.set_directories()
-        self.simulation_parameters(inflow=inflow)
+        if len(time) > 2:
+            self.simulation_parameters(fourier_mode=1,period=time[-1],bct_point_number=2*len(time),distal_resistance=distal_resistance)
+        else:
+            self.simulation_parameters(distal_resistance=distal_resistance)
+        self.flow_parameters(time=time,flow=flow)
         self.rom_parameters()
 
     def set_geometry_options(self,number_samples=50,use_distance_alignment_method=True):
@@ -232,7 +236,7 @@ class file_options:
                               fluid_viscosity=0.04, initial_pressure=0,
                               initial_velocity=[0.0001,0.0001,0.0001],
                               bct_analytical_shape='parabolic',
-                              inflow_file='inflow.flow',
+                              inflow_file='inflow',
                               period=1,bct_point_number=2,
                               fourier_mode=1,pressures=0,
                               svsolver='solver',number_timesteps=200,
@@ -267,7 +271,7 @@ class file_options:
                               sim_units_mm=False,
                               sim_units_cm=True,
                               global_edge_size=0.01,
-                              inflow=1):
+                              distal_resistance=0):
         # Assign PreSolver Constructor Values
         presolver_constructor = {'name':                           svpre_name,
                                  'fluid_density':               fluid_density,
@@ -275,7 +279,7 @@ class file_options:
                                  'initial_pressure':         initial_pressure,
                                  'initial_velocity':         initial_velocity,
                                  'bct_analytical_shape': bct_analytical_shape,
-                                 'inflow_file':                   inflow_file,
+                                 'inflow_file':        inflow_file+'_3d.flow',
                                  'period':                             period,
                                  'bct_point_number':         bct_point_number,
                                  'fourier_mode':                 fourier_mode,
@@ -314,8 +318,7 @@ class file_options:
                               'quadrature_interior':      quadrature_interior,
                               'quadrature_boundary':      quadrature_boundary,
                               'global_edge_size':            global_edge_size,
-                              'inflow':                                inflow,
-                              'inflow_file':                      inflow_file}
+                              'distal_resistance':          distal_resistance}
         indir = self.directory_constructor['data_folder']+'/{}-procs_case'.format(procs)
         outdir = self.directory_constructor['postprocessing_folder']
         if sim_units_mm and sim_units_cm:
@@ -339,18 +342,25 @@ class file_options:
         self.solver_constructor      = solver_constructor
         self.postsolver_constructor  = postsolver_constructor
         return
+    def flow_parameters(self,inflow_file='inflow',time=[0,1],flow=[1,1]):
+        flow_constructor = {'inflow_file':                        inflow_file,
+                            'time':                                      time,
+                            'flow':                                      flow}
+        self.flow_constructor = flow_constructor
 
-    def rom_parameters(self,zeroD=True,oneD=True,time_step=0.001,
+    def rom_parameters(self,inflow='inflow_rom.flow',zeroD=True,oneD=True,time_step=0.001,
                        number_time_steps=1000):
         rom0D_constructor = {'create': zeroD,
                              'model_order': 0,
                              'time_step': time_step,
-                             'number_time_steps': number_time_steps}
+                             'number_time_steps': number_time_steps,
+                             'inflow_file':  inflow}
 
         rom1D_constructor = {'create': oneD,
                              'model_order': 1,
                              'time_step': time_step,
-                             'number_time_steps': number_time_steps}
+                             'number_time_steps': number_time_steps,
+                             'inflow_file':   inflow}
 
         self.rom_constructor = {'0D': rom0D_constructor,
                                 '1D': rom1D_constructor}
